@@ -1478,8 +1478,8 @@ MakefileGenerator::usePlatformDir()
     project->variables()["OBJECTS_DIR"] = filePath 
 					+ (filePath.isEmpty() ? pltDir : slashPltDir);
 
-    filePath = project->first("QMAKE_LIBDIR_QT");
-    project->variables()["QMAKE_LIBDIR_QT"] = filePath 
+    filePath = project->first("QMAKE_LIBDIR_TQT");
+    project->variables()["QMAKE_LIBDIR_TQT"] = filePath 
 					    + (filePath.isEmpty() ? pltDir : slashPltDir);
 
     filePath = project->first("QMAKE_LIBS_QT");
@@ -2385,7 +2385,7 @@ MakefileGenerator::specdir()
 	return spec;
     spec = Option::mkfile::qmakespec;
 #if 0
-    if(const char *d = getenv("QTDIR")) {
+    if(const char *d = getenv("TQTDIR")) {
 	TQString qdir = Option::fixPathToTargetOS(TQString(d));
 	if(qdir.endsWith(TQString(TQChar(TQDir::separator()))))
 	    qdir.truncate(qdir.length()-1);
@@ -2395,7 +2395,7 @@ MakefileGenerator::specdir()
 	absSpec = Option::fixPathToTargetOS(absSpec);
 	//replace what you can
 	if(absSpec.startsWith(qdir)) {
-	    absSpec.replace(0, qdir.length(), "$(QTDIR)");
+	    absSpec.replace(0, qdir.length(), "$(TQTDIR)");
 	    spec = absSpec;
 	}
     }
