@@ -40,7 +40,7 @@
 
 #include "ntqtoolbox.h"
 
-#ifndef QT_NO_TOOLBOX
+#ifndef TQT_NO_TOOLBOX
 
 #include <ntqbutton.h>
 #include <ntqlayout.h>
@@ -690,4 +690,4 @@ void TQToolBox::itemRemoved( int index )
     Q_UNUSED(index)
 }
 
-#endif //QT_NO_TOOLBOX
+#endif //TQT_NO_TOOLBOX
